@@ -2,7 +2,6 @@ from .mapping import BaseDictKey
 from dataclasses import dataclass
 from typing import *
 from urllib.parse import urlparse
-import os
 import re
 from enum import Enum
 
@@ -59,6 +58,7 @@ class PlaceInput(BaseDictKey):
 class LocationInput(BaseDictKey):
     artifact: str
     representation: List[str]
+    artifact_archival_copy: str
 
     def validate(self):
         if self.representation is None and self.artifact is None:
@@ -75,6 +75,13 @@ class LocationInput(BaseDictKey):
             parse_res = urlparse(self.artifact)
             if parse_res.scheme not in ['http', 'https']:
                 errors.append(f'Artifact location must be http link. {self.artifact}')
+        if self.artifact_archival_copy:
+            parse_res = urlparse(self.artifact_archival_copy)
+            if parse_res.scheme not in ['http', 'https']:
+                errors.append(
+                    f'Artifact archival copy must be http link. '
+                    f'{self.artifact_archival_copy}'
+                )
         return errors
 
 
